@@ -4,7 +4,7 @@ use warnings;
 use Module::Pluggable::Object;
 use Test::More ();
 
-our $VERSION = '0.091';
+our $VERSION = '0.10';
 
 my $USE_OK = sub {
     eval "use $_[0];1;"; ## no critic
@@ -37,6 +37,11 @@ sub all_ok {
     my $fork        = delete $param{fork};
     my $shuffle     = delete $param{shuffle};
 
+    if ( _is_win() && $fork ) {
+        Test::More::plan skip_all => 'The "fork" option is not supported in Windows';
+        exit;
+    }
+
     my @checks;
     push @checks, +{ test => $USE_OK,     name => 'use: '     } if $use_ok;
     push @checks, +{ test => $REQUIRE_OK, name => 'require: ' } if $require_ok;
@@ -143,6 +148,10 @@ sub _is_excluded {
     _any { $module eq $_ || $module =~ /$_/ } @exceptions;
 }
 
+sub _is_win {
+    return ($^O && $^O eq 'MSWin32') ? 1 : 0;
+}
+
 1;
 
 __END__
@@ -230,6 +239,8 @@ If this option was set a value(1 or 2) then each check-code executes after forki
 
 This parameter is optional.
 
+NOTE that this option is not supported in Windows system.
+
 =item * B<shuffle> => boolean
 
 If this option was set the true value then modules will be sorted in random order.
